@@ -414,7 +414,7 @@ bool get_word_pair(char * line, char * & w1, char * & w2)
   *w2 = '\0';
   ++w2;
   w1 = trim_wspace(line);
-  w1 = trim_wspace(w2);
+  w2 = trim_wspace(w2);
   return true;
 }
 
@@ -492,7 +492,6 @@ void pipe()
     while (c = getchar(), c != '\n' && c != EOF)
       buf.push_back(static_cast<char>(c));
     buf.push_back('\0');
-    if (c == EOF) break;
     line = buf.data();
     ignore = 0;
     switch (line[0]) {
@@ -550,7 +549,7 @@ void pipe()
 	case 'r':
 	  switch(line[3]) {
 	  case 'a':
-	    if (get_word_pair(line + 3, word, word2))
+	    if (get_word_pair(line + 4, word, word2))
 	      aspell_speller_store_replacement(speller, word, -1, word2, -1);
 	    break;
 	  }
@@ -558,11 +557,11 @@ void pipe()
 	case 'c':
 	  switch (line[3]) {
 	  case 's':
-	    if (get_word_pair(line + 3, word, word2))
+	    if (get_word_pair(line + 4, word, word2))
 	      BREAK_ON_ERR(err = config->replace(word, word2));
 	    break;
 	  case 'r':
-	    word = trim_wspace(line + 3);
+	    word = trim_wspace(line + 4);
 	    BREAK_ON_ERR_SET(config->retrieve(word), 
 			     PosibErr<String>, ret);
 	    break;
@@ -589,7 +588,8 @@ void pipe()
     case '^':
       ignore = 1;
     default:
-      checker->process(line + ignore, strlen(line));
+      line += ignore;
+      checker->process(line, strlen(line));
       while (Token token = checker->next_misspelling()) {
 	word = line + token.offset;
 	word[token.len] = '\0';
@@ -600,7 +600,7 @@ void pipe()
 	if (!aspell_word_list_empty(suggestions)) {
 	  COUT << "& " << word 
 	       << " " << aspell_word_list_size(suggestions) 
-	       << " " << token.offset
+	       << " " << token.offset + ignore
 	       << ":";
 	  AspellStringEnumeration * els 
 	    = aspell_word_list_elements(suggestions);
@@ -636,6 +636,7 @@ void pipe()
       }
       COUT << "\n";
     }
+    if (c == EOF) break;
   }
 
   delete_aspell_speller(speller);
